@@ -1,7 +1,7 @@
 ;;; image.el --- image API
 
 ;; Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003,
-;;   2004, 2005, 2006 Free Software Foundation, Inc.
+;;   2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 ;; Maintainer: FSF
 ;; Keywords: multimedia
@@ -10,7 +10,7 @@
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
+;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
 
 ;; GNU Emacs is distributed in the hope that it will be useful,
@@ -35,11 +35,13 @@
 
 (defconst image-type-header-regexps
   '(("\\`/[\t\n\r ]*\\*.*XPM.\\*/" . xpm)
-    ("\\`P[1-6]" . pbm)
-    ("\\`GIF8" . gif)
-    ("\\`\211PNG\r\n" . png)
-    ("\\`[\t\n\r ]*#define" . xbm)
-    ("\\`\\(MM\0\\*\\|II\\*\0\\)" . tiff)
+    ("\\`P[1-6][[:space:]]+\\(?:#.*[[:space:]]+\\)*[0-9]+[[:space:]]+[0-9]+" . pbm)
+    ("\\`GIF8[79]a" . gif)
+    ("\\`\x89PNG\r\n\x1a\n" . png)
+    ("\\`[\t\n\r ]*#define \\([a-z0-9]+\\)_width [0-9]+\n\
+#define \\1_height [0-9]+\n\
+static char \\1_bits" . xbm)
+    ("\\`\\(?:MM\0\\*\\|II\\*\0\\)" . tiff)
     ("\\`[\t\n\r ]*%!PS" . postscript)
     ("\\`\xff\xd8" . (image-jpeg-p . jpeg)))
   "Alist of (REGEXP . IMAGE-TYPE) pairs used to auto-detect image types.
@@ -63,6 +65,27 @@ a non-nil value, TYPE is the image's type.")
 When the name of an image file match REGEXP, it is assumed to
 be of image type IMAGE-TYPE.")
 
+;; We rely on `auto-mode-alist' to detect xbm and xpm files, instead
+;; of content autodetection.  Their contents are just C code, so it is
+;; easy to generate false matches.
+(defvar image-type-auto-detectable
+  '((pbm . t)
+    (xbm . nil)
+    (bmp . maybe)
+    (gif . maybe)
+    (png . maybe)
+    (xpm . nil)
+    (jpeg . maybe)
+    (tiff . maybe)
+    (postscript . nil))
+  "Alist of (IMAGE-TYPE . AUTODETECT) pairs used to auto-detect image files.
+\(See `image-type-auto-detected-p').
+
+AUTODETECT can be
+ - t      always auto-detect.
+ - nil    never auto-detect.
+ - maybe  auto-detect only if the image type is available
+	    (see `image-type-available-p').")
 
 (defvar image-load-path nil
   "List of locations in which to search for image files.
@@ -292,24 +315,17 @@ use its file extension as image type.
 Optional DATA-P non-nil means FILE-OR-DATA is a string containing image data."
   (when (and (not data-p) (not (stringp file-or-data)))
     (error "Invalid image file name `%s'" file-or-data))
-  (cond ((null data-p)
-	 ;; FILE-OR-DATA is a file name.
-	 (unless (or type
-		     (setq type (image-type-from-file-header file-or-data)))
-	   (let ((extension (file-name-extension file-or-data)))
-	     (unless extension
-	       (error "Cannot determine image type"))
-	     (setq type (intern extension)))))
-	(t
-	 ;; FILE-OR-DATA contains image data.
-	 (unless type
-	   (setq type (image-type-from-data file-or-data)))))
   (unless type
-    (error "Cannot determine image type"))
-  (unless (symbolp type)
-    (error "Invalid image type `%s'" type))
+    (setq type (if data-p 
+                   (image-type-from-data file-or-data)
+                 (or (image-type-from-file-header file-or-data)
+                     (image-type-from-file-name file-or-data))))
+    (or type(error "Cannot determine image type")))
+  (or (memq type (and (boundp 'image-types) image-types))
+      (error "Invalid image type `%s'" type))
   type)
 
+
 ;;;###autoload
 (defun image-type-available-p (type)
   "Return non-nil if image type TYPE is available.
@@ -318,6 +334,20 @@ Image types are symbols like `xbm' or `jpeg'."
        (init-image-library type image-library-alist)))
 
 
+;;;###autoload
+(defun image-type-auto-detected-p ()
+  "Return t if the current buffer contains an auto-detectable image.
+This function is intended to be used from `magic-fallback-mode-alist'.
+
+The buffer is considered to contain an auto-detectable image if
+its beginning matches an image type in `image-type-header-regexps',
+and that image type is present in `image-type-auto-detectable'."
+  (let* ((type (image-type-from-buffer))
+	 (auto (and type (cdr (assq type image-type-auto-detectable)))))
+    (and auto
+	 (or (eq auto t) (image-type-available-p type)))))
+
+
 ;;;###autoload
 (defun create-image (file-or-data &optional type data-p &rest props)
   "Create an image.
