@@ -59,8 +59,14 @@ To get the frame's current cursor height, use `frame-parameters'."
 (defun mouse-set-font (&rest fonts)
   "Select an emacs font from a list of known good fonts and fontsets."
   (interactive
-   (x-popup-menu last-nonmenu-event
-		 (w32-generate-font-fontset-menu)))
+   (progn (unless (display-multi-font-p)
+	    (error "Cannot change fonts on this display"))
+	  (x-popup-menu
+	   (if (listp last-nonmenu-event)
+	       last-nonmenu-event
+	     (list '(0 0) (selected-window)))
+	   ;; Append list of fontsets currently defined.
+	   (w32-generate-font-fontset-menu))))
   (if fonts
       (let (font)
 	(while fonts
