@@ -14,6 +14,19 @@
 ;; If this directory is included in load-path, Emacs automatically
 ;; loads this file at startup time.
 
+(eval-after-load "quail/PY-b5"
+  '(quail-defrule "ling2" ?$(0!r(B nil t))
+(eval-after-load "quail/Punct"
+  '(quail-defrule " " ?$A!!(B nil t))
+(eval-after-load "quail/Punct-b5"
+  '(quail-defrule " " ?$(0!!(B nil t))
+(autoload 'ucs-input-activate "quail/uni-input"
+  "Activate UCS input method.
+With arg, activate UCS input method if and only if arg is positive.
+While this input method is active, the variable
+`input-method-function' is bound to the function `ucs-input-method'.")
+(register-input-method "ucs" "UTF-8" 'ucs-input-activate "U+"
+		       "Unicode input as hex in the form Uxxxx.")
 (register-input-method
  "chinese-zozy" "Chinese-BIG5" 'quail-use-package
  "$(0I\0D(B" "$(0&d'GTT&,!JI\@c0D5x!K(B"
@@ -112,7 +125,7 @@
  "quail/QJ")
 (register-input-method
  "chinese-qj-b5" "Chinese-BIG5" 'quail-use-package
- "$(0)A(BB" "$(0&d'GTT&,!J)A,1!K(B"
+ "$(0)A(BB" "$(0KH)tTT&,(B::$(0)A-F(B::"
  "quail/QJ-b5")
 (register-input-method
  "chinese-py-punct-b5" "Chinese-BIG5" 'quail-use-package
@@ -132,7 +145,7 @@
  "quail/py-punct")
 (register-input-method
  "chinese-py-b5" "Chinese-BIG5" 'quail-use-package
- "$(03<(BB" "$(0&d'GTT&,!J3<5x!K(B"
+ "$(03<(BB" "$(0KH)tTT&,(B::$(03<5x(B::"
  "quail/PY-b5")
 (register-input-method
  "chinese-punct" "Chinese-GB" 'quail-use-package
@@ -362,50 +375,14 @@
  "latin-5-alt-postfix" "Latin-5" 'quail-use-package
  "5<" "Latin-5 characters input method with postfix modifiers"
  "quail/latin-alt")
-(register-input-method
- "danish-alt-postfix" "Latin-1" 'quail-use-package
- "DA<" "Danish input method (rule: AE -> ,AF(B, OE -> ,AX(B, AA -> ,AE(B, E' -> ,AI(B)"
- "quail/latin-alt")
-(register-input-method
- "esperanto-alt-postfix" "Latin-3" 'quail-use-package
- "EO<" "Esperanto input method with postfix modifiers"
- "quail/latin-alt")
-(register-input-method
- "finnish-alt-postfix" "Latin-1" 'quail-use-package
- "FI<" "Finnish (Suomi) input method"
- "quail/latin-alt")
 (register-input-method
  "french-alt-postfix" "French" 'quail-use-package
  "FR<" "French (Fran,Ag(Bais) input method with postfix modifiers"
  "quail/latin-alt")
-(register-input-method
- "german-alt-postfix" "German" 'quail-use-package
- "DE<" "German (Deutsch) input method"
- "quail/latin-alt")
-(register-input-method
- "icelandic-alt-postfix" "Latin-1" 'quail-use-package
- "IS<" "Icelandic (,AM(Bslenska) input method with postfix modifiers"
- "quail/latin-alt")
 (register-input-method
  "italian-alt-postfix" "Latin-1" 'quail-use-package
  "IT<" "Italian (Italiano) input method with postfix modifiers"
  "quail/latin-alt")
-(register-input-method
- "norwegian-alt-postfix" "Latin-1" 'quail-use-package
- "NO<" "Norwegian (Norsk) input method (rule: AE->,AF(B, OE->,AX(B, AA->,AE(B, E'->,AI(B)"
- "quail/latin-alt")
-(register-input-method
- "scandinavian-alt-postfix" "Latin-1" 'quail-use-package
- "SC<" "Scandinavian input method with postfix modifiers"
- "quail/latin-alt")
-(register-input-method
- "spanish-alt-postfix" "Spanish" 'quail-use-package
- "ES<" "Spanish (Espa,Aq(Bol) input method with postfix modifiers"
- "quail/latin-alt")
-(register-input-method
- "swedish-alt-postfix" "Latin-1" 'quail-use-package
- "SV<" "Swedish (Svenska) input method (rule: AA -> ,AE(B, AE -> ,AD(B, OE -> ,AV(B, E' -> ,AI(B)"
- "quail/latin-alt")
 (register-input-method
  "turkish-latin-3-alt-postfix" "Turkish" 'quail-use-package
  "TR3<<" "Turkish (T,A|(Brk,Ag(Be) input method with postfix modifiers."
@@ -584,7 +561,7 @@
  "quail/greek")
 (register-input-method
  "greek-mizuochi" "Greek" 'quail-use-package
- "CG" ""
+ "CG" "The Mizuochi input method for Classical Greek using mule-unicode-0100-24ff."
  "quail/greek")
 (register-input-method
  "greek-babel" "Greek" 'quail-use-package
@@ -734,3 +711,16 @@
  "chinese-4corner" "Chinese-BIG5" 'quail-use-package
  "$(0(?-F(B" "$(0(?-FHAP#(B::"
  "quail/4Corner")
+(eval-after-load "quail/PY-b5"
+  '(quail-defrule "ling2" ?$(0!r(B nil t))
+(eval-after-load "quail/Punct"
+  '(quail-defrule " " ?$A!!(B nil t))
+(eval-after-load "quail/Punct-b5"
+  '(quail-defrule " " ?$(0!!(B nil t))
+(autoload 'ucs-input-activate "quail/uni-input"
+  "Activate UCS input method.
+With arg, activate UCS input method if and only if arg is positive.
+While this input method is active, the variable
+`input-method-function' is bound to the function `ucs-input-method'.")
+(register-input-method "ucs" "UTF-8" 'ucs-input-activate "U+"
+		       "Unicode input as hex in the form Uxxxx.")
